==> nextcloud-26.0.11.tgz: nextcloud/apps/updatenotification/l10n/ja.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} が利用可能です。アップデート方法について詳細情報を確認してください。",
    "Channel updated" : "チャンネルを更新しました",
    "Web updater is disabled" : "Webアップデータは無効になっています",
    "Update notifications" : "アップデート通知",
    "The update server could not be reached since %d days to check for new updates." : "%d日以降、新しい更新をチェックする更新サーバーにアクセスできませんでした。",
    "Please check the Nextcloud and server log files for errors." : "Nextcloudとサーバーログファイルでエラーがないか確認してください。",
    "Update to %1$s is available." : "%1$s への更新が利用可能です。",
    "Update to {serverAndVersion} is available." : "{serverAndVersion} へのアップデートが利用可能です。",
    "Update for {app} to version %s is available." : " {app} に対するバージョン %s へアップデートが利用可能です。",
    "Update notification" : "アップデート通知",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloudの更新通知を表示し、アップデータのSSOを提供します。",
    "Update" : "更新",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "あなたが実行しているバージョンはもうサポートされていません。 サポートされているバージョンにすみやかにアップデートしてください。",
    "Apps missing compatible version" : "対応バージョンがないアプリ",
    "View in store" : "ストア内で表示",
    "Apps with compatible version" : "対応バージョンのあるアプリ",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Webアップデーターは100人以上のユーザーがいる場合には推奨されていないことにご注意ください！代わりに、コマンドラインアップデーターをご使用ください！",
    "Open updater" : "アップデーターを開く",
    "Download now" : "今すぐダウンロード",
    "What's new?" : "新着情報？",
    "View changelog" : "変更履歴を確認する",
    "The update check is not yet finished. Please refresh the page." : "アップデートチェックが完了していません。ページを更新してください。",
    "Your version is up to date." : "最新版です。",
    "A non-default update server is in use to be checked for updates:" : "更新のチェックにデフォルト以外の更新サーバーが利用されています:",
    "Update channel" : "アップデートチャネル",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "アップデートチャネルを変更すると、アプリの管理ページにも影響が及びます。例えば、ベータチャネルに切り替えると、アプリ管理ページでベータ版のアップデートが提供されるようになります。",
    "Current update channel:" : "現在のアップデートチャネル:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "いつでも新しいバージョンにアップデートすることができます。 ただし、下位の安定したバージョンにダウングレードすることはできません",
    "Notify members of the following groups about available updates:" : "次のグループのメンバーに利用可能なアップデートを通知する:",
    "No groups" : "グループなし",
    "Only notifications for app updates are available." : "アプリのアップデートの通知のみが可能です。",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選択した更新チャネルでは、廃止サーバーについて専用の通知を行います。",
    "The selected update channel does not support updates of the server." : "選択したチャンネルでは、サーバーのアップデートをサポートしていません。",
    "A new version is available: <strong>{newVersionString}</strong>" : "新しいバージョンが利用可能です: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "新しいリリースの後、アップデートは最初のマイナーリリース以降にのみ表示されることに注意してください。新しいバージョンは時間の経過とともにユーザーに公開され、問題が見つかった場合はバージョンをスキップすることがあります。アップデートとリリースチャネルの詳細については、{link}をご覧ください。",
    "Checking apps for compatible versions" : "アプリの互換性のあるバージョンを確認する",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "config.phpで<samp>appstoreenabled</samp>がfalseに設定されていないことを確認してください。",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Appstoreに接続できなかったか、Appstoreからアップデートが返されませんでした。アップデートを手動で検索するか、サーバーがインターネットへアクセスでき、Appstoreに接続できることを確認してください。",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>全て</strong>のアプリが、このNextcloudのバージョンに対応しています。 ",
    "Enterprise" : "法人向け",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "法人向けです。 常に最新のパッチレベルを提供しますが、すぐに次のメジャーリリースにアップデートはしません。このアップデートはNextcloud GmbHが大規模でミッションクリティカルな開発のための追加の強化とテストを行った後に行われます。 このチャンネルは顧客だけが利用でき、Nextcloud Enterpriseパッケージを提供します。",
    "Stable" : "安定版",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "最新の安定版です。 通常の使用に適しており、常に最新のメジャーバージョンにアップデートされます。",
    "Beta" : "ベータ",
    "A pre-release version only for testing new features, not for production environments." : "本番環境ではなく、新機能のテスト専用のプレリリース版です。",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong>アプリが、このNextcloudバージョンと互換性があるバージョンではありません。"],
    "Please use the command line updater to update." : "コマンドラインアップデーターを使ってアップデートしてください。",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "以下からアップデートチャンネルを変更すると、アプリの管理ページにも影響します。例えば、ベータチャンネルに切り替えると、アプリ管理ページにて、ベータアプリの更新が通知されたりします。",
    "Update channel:" : "アップデートチャンネル:",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate} にチェックが入っています"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.4.tgz: nextcloud/apps/updatenotification/l10n/ja.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} が利用可能です。アップデート方法について詳細情報を確認してください。",
    "Channel updated" : "チャンネルを更新しました",
    "Web updater is disabled" : "Webアップデータは無効になっています",
    "Update notifications" : "アップデート通知",
    "The update server could not be reached since %d days to check for new updates." : "%d日以降、新しい更新をチェックする更新サーバーにアクセスできませんでした。",
    "Please check the Nextcloud and server log files for errors." : "Nextcloudとサーバーログファイルでエラーがないか確認してください。",
    "Update to %1$s is available." : "%1$s への更新が利用可能です。",
    "Update to {serverAndVersion} is available." : "{serverAndVersion} へのアップデートが利用可能です。",
    "Update for {app} to version %s is available." : " {app} に対するバージョン %s へアップデートが利用可能です。",
    "Update notification" : "アップデート通知",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloudの更新通知を表示し、アップデータのSSOを提供します。",
    "Update" : "更新",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "あなたが実行しているバージョンはもうサポートされていません。 サポートされているバージョンにすみやかにアップデートしてください。",
    "Apps missing compatible version" : "対応バージョンがないアプリ",
    "View in store" : "ストア内で表示",
    "Apps with compatible version" : "対応バージョンのあるアプリ",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Webアップデーターは100人以上のユーザーがいる場合には推奨されていないことにご注意ください！代わりに、コマンドラインアップデーターをご使用ください！",
    "Open updater" : "アップデーターを開く",
    "Download now" : "今すぐダウンロード",
    "Please use the command line updater to update." : "コマンドラインアップデーターを使ってアップデートしてください。",
    "What's new?" : "新着情報？",
    "View changelog" : "変更履歴を確認する",
    "The update check is not yet finished. Please refresh the page." : "アップデートチェックが完了していません。ページを更新してください。",
    "Your version is up to date." : "最新版です。",
    "A non-default update server is in use to be checked for updates:" : "更新のチェックにデフォルト以外の更新サーバーが利用されています:",
    "Update channel" : "アップデートチャネル",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "アップデートチャネルを変更すると、アプリの管理ページにも影響が及びます。例えば、ベータチャネルに切り替えると、アプリ管理ページでベータ版のアップデートが提供されるようになります。",
    "Current update channel:" : "現在のアップデートチャネル:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "いつでも新しいバージョンにアップデートすることができます。 ただし、下位の安定したバージョンにダウングレードすることはできません",
    "Notify members of the following groups about available updates:" : "次のグループのメンバーに利用可能なアップデートを通知する:",
    "No groups" : "グループなし",
    "Only notifications for app updates are available." : "アプリのアップデートの通知のみが可能です。",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選択した更新チャネルでは、廃止サーバーについて専用の通知を行います。",
    "The selected update channel does not support updates of the server." : "選択したチャンネルでは、サーバーのアップデートをサポートしていません。",
    "A new version is available: <strong>{newVersionString}</strong>" : "新しいバージョンが利用可能です: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "新しいリリースの後、アップデートは最初のマイナーリリース以降にのみ表示されることに注意してください。新しいバージョンは時間の経過とともにユーザーに公開され、問題が見つかった場合はバージョンをスキップすることがあります。アップデートとリリースチャネルの詳細については、{link}をご覧ください。",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate} にチェックが入っています",
    "Checking apps for compatible versions" : "アプリの互換性のあるバージョンを確認する",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "config.phpで<samp>appstoreenabled</samp>がfalseに設定されていないことを確認してください。",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Appstoreに接続できなかったか、Appstoreからアップデートが返されませんでした。アップデートを手動で検索するか、サーバーがインターネットへアクセスでき、Appstoreに接続できることを確認してください。",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>全て</strong>のアプリが、このNextcloudのバージョンに対応しています。 ",
    "Enterprise" : "法人向け",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "法人向けです。 常に最新のパッチレベルを提供しますが、すぐに次のメジャーリリースにアップデートはしません。このアップデートはNextcloud GmbHが大規模でミッションクリティカルな開発のための追加の強化とテストを行った後に行われます。 このチャンネルは顧客だけが利用でき、Nextcloud Enterpriseパッケージを提供します。",
    "Stable" : "安定版",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "最新の安定版です。 通常の使用に適しており、常に最新のメジャーバージョンにアップデートされます。",
    "Beta" : "ベータ",
    "A pre-release version only for testing new features, not for production environments." : "本番環境ではなく、新機能のテスト専用のプレリリース版です。",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong>アプリが、このNextcloudバージョンと互換性があるバージョンではありません。"],
    "Update for %1$s to version %2$s is available." : "%1$s に対するバージョン %2$s へアップデートが利用可能です。",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "以下からアップデートチャンネルを変更すると、アプリの管理ページにも影響します。例えば、ベータチャンネルに切り替えると、アプリ管理ページにて、ベータアプリの更新が通知されたりします。",
    "Update channel:" : "アップデートチャンネル:"
},
"nplurals=1; plural=0;");
